package Weed::Component;
use strict;
use warnings;

use Weed '
X3DComponent : X3DChildNode {
  SFNode [in,out] metadata NULL [X3DMetadataObject]
}
';

1;
__END__
